# coding: utf-8

"""
    Smooch

    The Smooch API is a unified interface for powering messaging in your customer experiences across every channel. Our API speeds access to new markets, reduces time to ship, eliminates complexity, and helps you build the best experiences for your customers. For more information, visit our [official documentation](https://docs.smooch.io).

    OpenAPI spec version: 5.16
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Deployment(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, id=None, status=None, hosting=None, base_url=None, username=None, phone_number=None, callback_url=None, callback_secret=None, integration_id=None, app_id=None):
        """
        Deployment - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'status': 'str',
            'hosting': 'str',
            'base_url': 'str',
            'username': 'str',
            'phone_number': 'str',
            'callback_url': 'str',
            'callback_secret': 'str',
            'integration_id': 'str',
            'app_id': 'str'
        }

        self.attribute_map = {
            'id': '_id',
            'status': 'status',
            'hosting': 'hosting',
            'base_url': 'baseUrl',
            'username': 'username',
            'phone_number': 'phoneNumber',
            'callback_url': 'callbackUrl',
            'callback_secret': 'callbackSecret',
            'integration_id': 'integrationId',
            'app_id': 'appId'
        }

        self._id = None
        self._status = None
        self._hosting = None
        self._base_url = None
        self._username = None
        self._phone_number = None
        self._callback_url = None
        self._callback_secret = None
        self._integration_id = None
        self._app_id = None

        # TODO: let required properties as mandatory parameter in the constructor.
        #       - to check if required property is not None (e.g. by calling setter)
        #       - ApiClient.__deserialize_model has to be adapted as well
        if id is not None:
          self.id = id
        if status is not None:
          self.status = status
        if hosting is not None:
          self.hosting = hosting
        if base_url is not None:
          self.base_url = base_url
        if username is not None:
          self.username = username
        if phone_number is not None:
          self.phone_number = phone_number
        if callback_url is not None:
          self.callback_url = callback_url
        if callback_secret is not None:
          self.callback_secret = callback_secret
        if integration_id is not None:
          self.integration_id = integration_id
        if app_id is not None:
          self.app_id = app_id

    @property
    def id(self):
        """
        Gets the id of this Deployment.
        The deployment ID, generated automatically.

        :return: The id of this Deployment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Deployment.
        The deployment ID, generated automatically.

        :param id: The id of this Deployment.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def status(self):
        """
        Gets the status of this Deployment.
        The deployment status. See [**DeploymentStatusEnum**](Enums.md#DeploymentStatusEnum) for available values.

        :return: The status of this Deployment.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Deployment.
        The deployment status. See [**DeploymentStatusEnum**](Enums.md#DeploymentStatusEnum) for available values.

        :param status: The status of this Deployment.
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")

        self._status = status

    @property
    def hosting(self):
        """
        Gets the hosting of this Deployment.
        The deployment hosting. See [**DeploymentHostingEnum**](Enums.md#DeploymentHostingEnum) for available values.

        :return: The hosting of this Deployment.
        :rtype: str
        """
        return self._hosting

    @hosting.setter
    def hosting(self, hosting):
        """
        Sets the hosting of this Deployment.
        The deployment hosting. See [**DeploymentHostingEnum**](Enums.md#DeploymentHostingEnum) for available values.

        :param hosting: The hosting of this Deployment.
        :type: str
        """
        if hosting is None:
            raise ValueError("Invalid value for `hosting`, must not be `None`")

        self._hosting = hosting

    @property
    def base_url(self):
        """
        Gets the base_url of this Deployment.
        The baseUrl of the deployment. Only present for `self` hosted deployments.

        :return: The base_url of this Deployment.
        :rtype: str
        """
        return self._base_url

    @base_url.setter
    def base_url(self, base_url):
        """
        Sets the base_url of this Deployment.
        The baseUrl of the deployment. Only present for `self` hosted deployments.

        :param base_url: The base_url of this Deployment.
        :type: str
        """

        self._base_url = base_url

    @property
    def username(self):
        """
        Gets the username of this Deployment.
        The username of the deployment. Only present for `self` hosted deployments.

        :return: The username of this Deployment.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this Deployment.
        The username of the deployment. Only present for `self` hosted deployments.

        :param username: The username of this Deployment.
        :type: str
        """

        self._username = username

    @property
    def phone_number(self):
        """
        Gets the phone_number of this Deployment.
        The phoneNumber of the deployment. Only present once the deployment has been registered.

        :return: The phone_number of this Deployment.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this Deployment.
        The phoneNumber of the deployment. Only present once the deployment has been registered.

        :param phone_number: The phone_number of this Deployment.
        :type: str
        """

        self._phone_number = phone_number

    @property
    def callback_url(self):
        """
        Gets the callback_url of this Deployment.
        The URL to be called by Smooch when the status of the deployment changes.

        :return: The callback_url of this Deployment.
        :rtype: str
        """
        return self._callback_url

    @callback_url.setter
    def callback_url(self, callback_url):
        """
        Sets the callback_url of this Deployment.
        The URL to be called by Smooch when the status of the deployment changes.

        :param callback_url: The callback_url of this Deployment.
        :type: str
        """

        self._callback_url = callback_url

    @property
    def callback_secret(self):
        """
        Gets the callback_secret of this Deployment.
        The secret used to secure the callback.

        :return: The callback_secret of this Deployment.
        :rtype: str
        """
        return self._callback_secret

    @callback_secret.setter
    def callback_secret(self, callback_secret):
        """
        Sets the callback_secret of this Deployment.
        The secret used to secure the callback.

        :param callback_secret: The callback_secret of this Deployment.
        :type: str
        """

        self._callback_secret = callback_secret

    @property
    def integration_id(self):
        """
        Gets the integration_id of this Deployment.
        The integrationId of the integration using this deployment.

        :return: The integration_id of this Deployment.
        :rtype: str
        """
        return self._integration_id

    @integration_id.setter
    def integration_id(self, integration_id):
        """
        Sets the integration_id of this Deployment.
        The integrationId of the integration using this deployment.

        :param integration_id: The integration_id of this Deployment.
        :type: str
        """

        self._integration_id = integration_id

    @property
    def app_id(self):
        """
        Gets the app_id of this Deployment.
        The appId of the integration using this deployment.

        :return: The app_id of this Deployment.
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """
        Sets the app_id of this Deployment.
        The appId of the integration using this deployment.

        :param app_id: The app_id of this Deployment.
        :type: str
        """

        self._app_id = app_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Deployment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Smooch

    The Smooch API is a unified interface for powering messaging in your customer experiences across every channel. Our API speeds access to new markets, reduces time to ship, eliminates complexity, and helps you build the best experiences for your customers. For more information, visit our [official documentation](https://docs.smooch.io).

    OpenAPI spec version: 5.16
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class DeploymentCreate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, hosting=None, base_url=None, username=None, password=None, callback_url=None):
        """
        DeploymentCreate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'hosting': 'str',
            'base_url': 'str',
            'username': 'str',
            'password': 'str',
            'callback_url': 'str'
        }

        self.attribute_map = {
            'hosting': 'hosting',
            'base_url': 'baseUrl',
            'username': 'username',
            'password': 'password',
            'callback_url': 'callbackUrl'
        }

        self._hosting = None
        self._base_url = None
        self._username = None
        self._password = None
        self._callback_url = None

        # TODO: let required properties as mandatory parameter in the constructor.
        #       - to check if required property is not None (e.g. by calling setter)
        #       - ApiClient.__deserialize_model has to be adapted as well
        if hosting is not None:
          self.hosting = hosting
        if base_url is not None:
          self.base_url = base_url
        if username is not None:
          self.username = username
        if password is not None:
          self.password = password
        if callback_url is not None:
          self.callback_url = callback_url

    @property
    def hosting(self):
        """
        Gets the hosting of this DeploymentCreate.
        The deployment hosting. See [**DeploymentHostingEnum**](Enums.md#DeploymentHostingEnum) for available values.

        :return: The hosting of this DeploymentCreate.
        :rtype: str
        """
        return self._hosting

    @hosting.setter
    def hosting(self, hosting):
        """
        Sets the hosting of this DeploymentCreate.
        The deployment hosting. See [**DeploymentHostingEnum**](Enums.md#DeploymentHostingEnum) for available values.

        :param hosting: The hosting of this DeploymentCreate.
        :type: str
        """
        if hosting is None:
            raise ValueError("Invalid value for `hosting`, must not be `None`")

        self._hosting = hosting

    @property
    def base_url(self):
        """
        Gets the base_url of this DeploymentCreate.
        The base URL to access your WhatsApp EC. Only provide for `self` hosted deployments.

        :return: The base_url of this DeploymentCreate.
        :rtype: str
        """
        return self._base_url

    @base_url.setter
    def base_url(self, base_url):
        """
        Sets the base_url of this DeploymentCreate.
        The base URL to access your WhatsApp EC. Only provide for `self` hosted deployments.

        :param base_url: The base_url of this DeploymentCreate.
        :type: str
        """

        self._base_url = base_url

    @property
    def username(self):
        """
        Gets the username of this DeploymentCreate.
        The username to access your WhatsApp EC. Only provide for `self` hosted deployments.

        :return: The username of this DeploymentCreate.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this DeploymentCreate.
        The username to access your WhatsApp EC. Only provide for `self` hosted deployments.

        :param username: The username of this DeploymentCreate.
        :type: str
        """

        self._username = username

    @property
    def password(self):
        """
        Gets the password of this DeploymentCreate.
        The password to access your WhatsApp EC. Only provide for `self` hosted deployments.

        :return: The password of this DeploymentCreate.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password of this DeploymentCreate.
        The password to access your WhatsApp EC. Only provide for `self` hosted deployments.

        :param password: The password of this DeploymentCreate.
        :type: str
        """

        self._password = password

    @property
    def callback_url(self):
        """
        Gets the callback_url of this DeploymentCreate.
        The URL to be called by Smooch when the status of the deployment changes.

        :return: The callback_url of this DeploymentCreate.
        :rtype: str
        """
        return self._callback_url

    @callback_url.setter
    def callback_url(self, callback_url):
        """
        Sets the callback_url of this DeploymentCreate.
        The URL to be called by Smooch when the status of the deployment changes.

        :param callback_url: The callback_url of this DeploymentCreate.
        :type: str
        """

        self._callback_url = callback_url

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DeploymentCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Smooch

    The Smooch API is a unified interface for powering messaging in your customer experiences across every channel. Our API speeds access to new markets, reduces time to ship, eliminates complexity, and helps you build the best experiences for your customers. For more information, visit our [official documentation](https://docs.smooch.io).

    OpenAPI spec version: 5.16
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class IntegrationUpdate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, display_name=None, brand_color=None, fixed_intro_pane=None, conversation_color=None, action_color=None, display_style=None, button_icon_url=None, button_width=None, button_height=None, integration_order=None, business_name=None, business_icon_url=None, background_image_url=None, origin_whitelist=None, channel_id=None, channel_secret=None, service_code=None, switcher_secret=None, hsm_fallback_language=None, qr_code_url=None, hide_unsubscribe_link=None):
        """
        IntegrationUpdate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'display_name': 'str',
            'brand_color': 'str',
            'fixed_intro_pane': 'bool',
            'conversation_color': 'str',
            'action_color': 'str',
            'display_style': 'str',
            'button_icon_url': 'str',
            'button_width': 'str',
            'button_height': 'str',
            'integration_order': 'list[str]',
            'business_name': 'str',
            'business_icon_url': 'str',
            'background_image_url': 'str',
            'origin_whitelist': 'list[str]',
            'channel_id': 'str',
            'channel_secret': 'str',
            'service_code': 'str',
            'switcher_secret': 'str',
            'hsm_fallback_language': 'str',
            'qr_code_url': 'str',
            'hide_unsubscribe_link': 'bool'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'brand_color': 'brandColor',
            'fixed_intro_pane': 'fixedIntroPane',
            'conversation_color': 'conversationColor',
            'action_color': 'actionColor',
            'display_style': 'displayStyle',
            'button_icon_url': 'buttonIconUrl',
            'button_width': 'buttonWidth',
            'button_height': 'buttonHeight',
            'integration_order': 'integrationOrder',
            'business_name': 'businessName',
            'business_icon_url': 'businessIconUrl',
            'background_image_url': 'backgroundImageUrl',
            'origin_whitelist': 'originWhitelist',
            'channel_id': 'channelId',
            'channel_secret': 'channelSecret',
            'service_code': 'serviceCode',
            'switcher_secret': 'switcherSecret',
            'hsm_fallback_language': 'hsmFallbackLanguage',
            'qr_code_url': 'qrCodeUrl',
            'hide_unsubscribe_link': 'hideUnsubscribeLink'
        }

        self._display_name = None
        self._brand_color = None
        self._fixed_intro_pane = None
        self._conversation_color = None
        self._action_color = None
        self._display_style = None
        self._button_icon_url = None
        self._button_width = None
        self._button_height = None
        self._integration_order = None
        self._business_name = None
        self._business_icon_url = None
        self._background_image_url = None
        self._origin_whitelist = None
        self._channel_id = None
        self._channel_secret = None
        self._service_code = None
        self._switcher_secret = None
        self._hsm_fallback_language = None
        self._qr_code_url = None
        self._hide_unsubscribe_link = None

        # TODO: let required properties as mandatory parameter in the constructor.
        #       - to check if required property is not None (e.g. by calling setter)
        #       - ApiClient.__deserialize_model has to be adapted as well
        if display_name is not None:
          self.display_name = display_name
        if brand_color is not None:
          self.brand_color = brand_color
        if fixed_intro_pane is not None:
          self.fixed_intro_pane = fixed_intro_pane
        if conversation_color is not None:
          self.conversation_color = conversation_color
        if action_color is not None:
          self.action_color = action_color
        if display_style is not None:
          self.display_style = display_style
        if button_icon_url is not None:
          self.button_icon_url = button_icon_url
        if button_width is not None:
          self.button_width = button_width
        if button_height is not None:
          self.button_height = button_height
        if integration_order is not None:
          self.integration_order = integration_order
        if business_name is not None:
          self.business_name = business_name
        if business_icon_url is not None:
          self.business_icon_url = business_icon_url
        if background_image_url is not None:
          self.background_image_url = background_image_url
        if origin_whitelist is not None:
          self.origin_whitelist = origin_whitelist
        if channel_id is not None:
          self.channel_id = channel_id
        if channel_secret is not None:
          self.channel_secret = channel_secret
        if service_code is not None:
          self.service_code = service_code
        if switcher_secret is not None:
          self.switcher_secret = switcher_secret
        if hsm_fallback_language is not None:
          self.hsm_fallback_language = hsm_fallback_language
        if qr_code_url is not None:
          self.qr_code_url = qr_code_url
        if hide_unsubscribe_link is not None:
          self.hide_unsubscribe_link = hide_unsubscribe_link

    @property
    def display_name(self):
        """
        Gets the display_name of this IntegrationUpdate.
        The integration display name. Used to map a human-friendly name to an integration. 

        :return: The display_name of this IntegrationUpdate.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this IntegrationUpdate.
        The integration display name. Used to map a human-friendly name to an integration. 

        :param display_name: The display_name of this IntegrationUpdate.
        :type: str
        """

        self._display_name = display_name

    @property
    def brand_color(self):
        """
        Gets the brand_color of this IntegrationUpdate.
        This color will be used in the messenger header and the button or tab in idle state. (Optional) Used for *Web Messenger* integrations. 

        :return: The brand_color of this IntegrationUpdate.
        :rtype: str
        """
        return self._brand_color

    @brand_color.setter
    def brand_color(self, brand_color):
        """
        Sets the brand_color of this IntegrationUpdate.
        This color will be used in the messenger header and the button or tab in idle state. (Optional) Used for *Web Messenger* integrations. 

        :param brand_color: The brand_color of this IntegrationUpdate.
        :type: str
        """

        self._brand_color = brand_color

    @property
    def fixed_intro_pane(self):
        """
        Gets the fixed_intro_pane of this IntegrationUpdate.
        When `true`, the introduction pane will be pinned at the top of the conversation instead of scrolling with it. The default value is `false`. (Optional) Used for *Web Messenger* integrations. 

        :return: The fixed_intro_pane of this IntegrationUpdate.
        :rtype: bool
        """
        return self._fixed_intro_pane

    @fixed_intro_pane.setter
    def fixed_intro_pane(self, fixed_intro_pane):
        """
        Sets the fixed_intro_pane of this IntegrationUpdate.
        When `true`, the introduction pane will be pinned at the top of the conversation instead of scrolling with it. The default value is `false`. (Optional) Used for *Web Messenger* integrations. 

        :param fixed_intro_pane: The fixed_intro_pane of this IntegrationUpdate.
        :type: bool
        """

        self._fixed_intro_pane = fixed_intro_pane

    @property
    def conversation_color(self):
        """
        Gets the conversation_color of this IntegrationUpdate.
        This color will be used for customer messages, quick replies and actions in the footer. (Optional) Used for *Web Messenger* integrations. 

        :return: The conversation_color of this IntegrationUpdate.
        :rtype: str
        """
        return self._conversation_color

    @conversation_color.setter
    def conversation_color(self, conversation_color):
        """
        Sets the conversation_color of this IntegrationUpdate.
        This color will be used for customer messages, quick replies and actions in the footer. (Optional) Used for *Web Messenger* integrations. 

        :param conversation_color: The conversation_color of this IntegrationUpdate.
        :type: str
        """

        self._conversation_color = conversation_color

    @property
    def action_color(self):
        """
        Gets the action_color of this IntegrationUpdate.
        This color will be used for call-to-actions inside your messages. (Optional) Used for *Web Messenger* integrations. 

        :return: The action_color of this IntegrationUpdate.
        :rtype: str
        """
        return self._action_color

    @action_color.setter
    def action_color(self, action_color):
        """
        Sets the action_color of this IntegrationUpdate.
        This color will be used for call-to-actions inside your messages. (Optional) Used for *Web Messenger* integrations. 

        :param action_color: The action_color of this IntegrationUpdate.
        :type: str
        """

        self._action_color = action_color

    @property
    def display_style(self):
        """
        Gets the display_style of this IntegrationUpdate.
        Choose how the messenger will appear on your website. Must be either button or tab. (Optional) Used for *Web Messenger* integrations. 

        :return: The display_style of this IntegrationUpdate.
        :rtype: str
        """
        return self._display_style

    @display_style.setter
    def display_style(self, display_style):
        """
        Sets the display_style of this IntegrationUpdate.
        Choose how the messenger will appear on your website. Must be either button or tab. (Optional) Used for *Web Messenger* integrations. 

        :param display_style: The display_style of this IntegrationUpdate.
        :type: str
        """

        self._display_style = display_style

    @property
    def button_icon_url(self):
        """
        Gets the button_icon_url of this IntegrationUpdate.
        With the button style Web Messenger, you have the option of selecting your own button icon. (Optional) Used for *Web Messenger* integrations. 

        :return: The button_icon_url of this IntegrationUpdate.
        :rtype: str
        """
        return self._button_icon_url

    @button_icon_url.setter
    def button_icon_url(self, button_icon_url):
        """
        Sets the button_icon_url of this IntegrationUpdate.
        With the button style Web Messenger, you have the option of selecting your own button icon. (Optional) Used for *Web Messenger* integrations. 

        :param button_icon_url: The button_icon_url of this IntegrationUpdate.
        :type: str
        """

        self._button_icon_url = button_icon_url

    @property
    def button_width(self):
        """
        Gets the button_width of this IntegrationUpdate.
        With the button style Web Messenger, you have the option of specifying its width. (Optional) Used for *Web Messenger* integrations. 

        :return: The button_width of this IntegrationUpdate.
        :rtype: str
        """
        return self._button_width

    @button_width.setter
    def button_width(self, button_width):
        """
        Sets the button_width of this IntegrationUpdate.
        With the button style Web Messenger, you have the option of specifying its width. (Optional) Used for *Web Messenger* integrations. 

        :param button_width: The button_width of this IntegrationUpdate.
        :type: str
        """

        self._button_width = button_width

    @property
    def button_height(self):
        """
        Gets the button_height of this IntegrationUpdate.
        With the button style Web Messenger, you have the option of specifying its height. (Optional) Used for *Web Messenger* integrations. 

        :return: The button_height of this IntegrationUpdate.
        :rtype: str
        """
        return self._button_height

    @button_height.setter
    def button_height(self, button_height):
        """
        Sets the button_height of this IntegrationUpdate.
        With the button style Web Messenger, you have the option of specifying its height. (Optional) Used for *Web Messenger* integrations. 

        :param button_height: The button_height of this IntegrationUpdate.
        :type: str
        """

        self._button_height = button_height

    @property
    def integration_order(self):
        """
        Gets the integration_order of this IntegrationUpdate.
        Array of integration IDs, order will be reflected in the Web Messenger. When set, only integrations from this list will be displayed in the Web Messenger. If unset, all integrations will be displayed (Optional) Used for *Web Messenger* integrations. 

        :return: The integration_order of this IntegrationUpdate.
        :rtype: list[str]
        """
        return self._integration_order

    @integration_order.setter
    def integration_order(self, integration_order):
        """
        Sets the integration_order of this IntegrationUpdate.
        Array of integration IDs, order will be reflected in the Web Messenger. When set, only integrations from this list will be displayed in the Web Messenger. If unset, all integrations will be displayed (Optional) Used for *Web Messenger* integrations. 

        :param integration_order: The integration_order of this IntegrationUpdate.
        :type: list[str]
        """

        self._integration_order = integration_order

    @property
    def business_name(self):
        """
        Gets the business_name of this IntegrationUpdate.
        A custom business name for the Web Messenger. (Optional) Used for *Web Messenger* integrations. 

        :return: The business_name of this IntegrationUpdate.
        :rtype: str
        """
        return self._business_name

    @business_name.setter
    def business_name(self, business_name):
        """
        Sets the business_name of this IntegrationUpdate.
        A custom business name for the Web Messenger. (Optional) Used for *Web Messenger* integrations. 

        :param business_name: The business_name of this IntegrationUpdate.
        :type: str
        """

        self._business_name = business_name

    @property
    def business_icon_url(self):
        """
        Gets the business_icon_url of this IntegrationUpdate.
        A custom business icon url for the Web Messenger. (Optional) Used for *Web Messenger* integrations. 

        :return: The business_icon_url of this IntegrationUpdate.
        :rtype: str
        """
        return self._business_icon_url

    @business_icon_url.setter
    def business_icon_url(self, business_icon_url):
        """
        Sets the business_icon_url of this IntegrationUpdate.
        A custom business icon url for the Web Messenger. (Optional) Used for *Web Messenger* integrations. 

        :param business_icon_url: The business_icon_url of this IntegrationUpdate.
        :type: str
        """

        self._business_icon_url = business_icon_url

    @property
    def background_image_url(self):
        """
        Gets the background_image_url of this IntegrationUpdate.
        A custom background url for the Web Messenger. (Optional) Used for *Web Messenger* integrations. 

        :return: The background_image_url of this IntegrationUpdate.
        :rtype: str
        """
        return self._background_image_url

    @background_image_url.setter
    def background_image_url(self, background_image_url):
        """
        Sets the background_image_url of this IntegrationUpdate.
        A custom background url for the Web Messenger. (Optional) Used for *Web Messenger* integrations. 

        :param background_image_url: The background_image_url of this IntegrationUpdate.
        :type: str
        """

        self._background_image_url = background_image_url

    @property
    def origin_whitelist(self):
        """
        Gets the origin_whitelist of this IntegrationUpdate.
        A list of origins to whitelist. When set, only the origins from this list will be able to initialize the Web Messenger. If unset, all origins are whitelisted. The elements in the list should follow the serialized-origin format from RFC 6454 `scheme \"://\" host [ \":\" port ]`, where scheme is `http` or `https`. (Optional) Used for *Web Messenger* integrations. 

        :return: The origin_whitelist of this IntegrationUpdate.
        :rtype: list[str]
        """
        return self._origin_whitelist

    @origin_whitelist.setter
    def origin_whitelist(self, origin_whitelist):
        """
        Sets the origin_whitelist of this IntegrationUpdate.
        A list of origins to whitelist. When set, only the origins from this list will be able to initialize the Web Messenger. If unset, all origins are whitelisted. The elements in the list should follow the serialized-origin format from RFC 6454 `scheme \"://\" host [ \":\" port ]`, where scheme is `http` or `https`. (Optional) Used for *Web Messenger* integrations. 

        :param origin_whitelist: The origin_whitelist of this IntegrationUpdate.
        :type: list[str]
        """

        self._origin_whitelist = origin_whitelist

    @property
    def channel_id(self):
        """
        Gets the channel_id of this IntegrationUpdate.
        LINE Channel ID. Required for *line* integrations. 

        :return: The channel_id of this IntegrationUpdate.
        :rtype: str
        """
        return self._channel_id

    @channel_id.setter
    def channel_id(self, channel_id):
        """
        Sets the channel_id of this IntegrationUpdate.
        LINE Channel ID. Required for *line* integrations. 

        :param channel_id: The channel_id of this IntegrationUpdate.
        :type: str
        """

        self._channel_id = channel_id

    @property
    def channel_secret(self):
        """
        Gets the channel_secret of this IntegrationUpdate.
        LINE Channel Secret. Required for *line* integrations. 

        :return: The channel_secret of this IntegrationUpdate.
        :rtype: str
        """
        return self._channel_secret

    @channel_secret.setter
    def channel_secret(self, channel_secret):
        """
        Sets the channel_secret of this IntegrationUpdate.
        LINE Channel Secret. Required for *line* integrations. 

        :param channel_secret: The channel_secret of this IntegrationUpdate.
        :type: str
        """

        self._channel_secret = channel_secret

    @property
    def service_code(self):
        """
        Gets the service_code of this IntegrationUpdate.
        LINE Service Code. 

        :return: The service_code of this IntegrationUpdate.
        :rtype: str
        """
        return self._service_code

    @service_code.setter
    def service_code(self, service_code):
        """
        Sets the service_code of this IntegrationUpdate.
        LINE Service Code. 

        :param service_code: The service_code of this IntegrationUpdate.
        :type: str
        """

        self._service_code = service_code

    @property
    def switcher_secret(self):
        """
        Gets the switcher_secret of this IntegrationUpdate.
        LINE Switcher Secret. 

        :return: The switcher_secret of this IntegrationUpdate.
        :rtype: str
        """
        return self._switcher_secret

    @switcher_secret.setter
    def switcher_secret(self, switcher_secret):
        """
        Sets the switcher_secret of this IntegrationUpdate.
        LINE Switcher Secret. 

        :param switcher_secret: The switcher_secret of this IntegrationUpdate.
        :type: str
        """

        self._switcher_secret = switcher_secret

    @property
    def hsm_fallback_language(self):
        """
        Gets the hsm_fallback_language of this IntegrationUpdate.
        Specification of a fallback language. (Optional) Used for *WhatsApp* integrations. 

        :return: The hsm_fallback_language of this IntegrationUpdate.
        :rtype: str
        """
        return self._hsm_fallback_language

    @hsm_fallback_language.setter
    def hsm_fallback_language(self, hsm_fallback_language):
        """
        Sets the hsm_fallback_language of this IntegrationUpdate.
        Specification of a fallback language. (Optional) Used for *WhatsApp* integrations. 

        :param hsm_fallback_language: The hsm_fallback_language of this IntegrationUpdate.
        :type: str
        """

        self._hsm_fallback_language = hsm_fallback_language

    @property
    def qr_code_url(self):
        """
        Gets the qr_code_url of this IntegrationUpdate.
        URL provided by LINE in the [Developer Console](https://developers.line.biz/console/). 

        :return: The qr_code_url of this IntegrationUpdate.
        :rtype: str
        """
        return self._qr_code_url

    @qr_code_url.setter
    def qr_code_url(self, qr_code_url):
        """
        Sets the qr_code_url of this IntegrationUpdate.
        URL provided by LINE in the [Developer Console](https://developers.line.biz/console/). 

        :param qr_code_url: The qr_code_url of this IntegrationUpdate.
        :type: str
        """

        self._qr_code_url = qr_code_url

    @property
    def hide_unsubscribe_link(self):
        """
        Gets the hide_unsubscribe_link of this IntegrationUpdate.
        When `true`, unsubscribe links will not be included in outbound emails. If this setting is enabled, it is expected that the business is providing the user a way to unsubscribe by some other means. (Optional) Used for *mailgun* integrations. 

        :return: The hide_unsubscribe_link of this IntegrationUpdate.
        :rtype: bool
        """
        return self._hide_unsubscribe_link

    @hide_unsubscribe_link.setter
    def hide_unsubscribe_link(self, hide_unsubscribe_link):
        """
        Sets the hide_unsubscribe_link of this IntegrationUpdate.
        When `true`, unsubscribe links will not be included in outbound emails. If this setting is enabled, it is expected that the business is providing the user a way to unsubscribe by some other means. (Optional) Used for *mailgun* integrations. 

        :param hide_unsubscribe_link: The hide_unsubscribe_link of this IntegrationUpdate.
        :type: bool
        """

        self._hide_unsubscribe_link = hide_unsubscribe_link

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, IntegrationUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Smooch

    The Smooch API is a unified interface for powering messaging in your customer experiences across every channel. Our API speeds access to new markets, reduces time to ship, eliminates complexity, and helps you build the best experiences for your customers. For more information, visit our [official documentation](https://docs.smooch.io).

    OpenAPI spec version: 5.16
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Enums(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, action_size=None, action_type=None, business_system_type=None, client_status=None, confirmation_type=None, conversation_activity_type=None, deployment_activation_method=None, deployment_hosting=None, deployment_status=None, image_aspect_ratio=None, integration_status=None, integration_type=None, menu_item_type=None, message_item_size=None, message_type=None, field_type=None, quoted_message_type=None, role=None, webhook_triggers=None):
        """
        Enums - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'action_size': 'str',
            'action_type': 'str',
            'business_system_type': 'str',
            'client_status': 'str',
            'confirmation_type': 'str',
            'conversation_activity_type': 'str',
            'deployment_activation_method': 'str',
            'deployment_hosting': 'str',
            'deployment_status': 'str',
            'image_aspect_ratio': 'str',
            'integration_status': 'str',
            'integration_type': 'str',
            'menu_item_type': 'str',
            'message_item_size': 'str',
            'message_type': 'str',
            'field_type': 'str',
            'quoted_message_type': 'str',
            'role': 'str',
            'webhook_triggers': 'str'
        }

        self.attribute_map = {
            'action_size': 'ActionSize',
            'action_type': 'ActionType',
            'business_system_type': 'BusinessSystemType',
            'client_status': 'ClientStatus',
            'confirmation_type': 'ConfirmationType',
            'conversation_activity_type': 'ConversationActivityType',
            'deployment_activation_method': 'DeploymentActivationMethod',
            'deployment_hosting': 'DeploymentHosting',
            'deployment_status': 'DeploymentStatus',
            'image_aspect_ratio': 'ImageAspectRatio',
            'integration_status': 'IntegrationStatus',
            'integration_type': 'IntegrationType',
            'menu_item_type': 'MenuItemType',
            'message_item_size': 'MessageItemSize',
            'message_type': 'MessageType',
            'field_type': 'FieldType',
            'quoted_message_type': 'QuotedMessageType',
            'role': 'Role',
            'webhook_triggers': 'WebhookTriggers'
        }

        self._action_size = None
        self._action_type = None
        self._business_system_type = None
        self._client_status = None
        self._confirmation_type = None
        self._conversation_activity_type = None
        self._deployment_activation_method = None
        self._deployment_hosting = None
        self._deployment_status = None
        self._image_aspect_ratio = None
        self._integration_status = None
        self._integration_type = None
        self._menu_item_type = None
        self._message_item_size = None
        self._message_type = None
        self._field_type = None
        self._quoted_message_type = None
        self._role = None
        self._webhook_triggers = None

        # TODO: let required properties as mandatory parameter in the constructor.
        #       - to check if required property is not None (e.g. by calling setter)
        #       - ApiClient.__deserialize_model has to be adapted as well
        if action_size is not None:
          self.action_size = action_size
        if action_type is not None:
          self.action_type = action_type
        if business_system_type is not None:
          self.business_system_type = business_system_type
        if client_status is not None:
          self.client_status = client_status
        if confirmation_type is not None:
          self.confirmation_type = confirmation_type
        if conversation_activity_type is not None:
          self.conversation_activity_type = conversation_activity_type
        if deployment_activation_method is not None:
          self.deployment_activation_method = deployment_activation_method
        if deployment_hosting is not None:
          self.deployment_hosting = deployment_hosting
        if deployment_status is not None:
          self.deployment_status = deployment_status
        if image_aspect_ratio is not None:
          self.image_aspect_ratio = image_aspect_ratio
        if integration_status is not None:
          self.integration_status = integration_status
        if integration_type is not None:
          self.integration_type = integration_type
        if menu_item_type is not None:
          self.menu_item_type = menu_item_type
        if message_item_size is not None:
          self.message_item_size = message_item_size
        if message_type is not None:
          self.message_type = message_type
        if field_type is not None:
          self.field_type = field_type
        if quoted_message_type is not None:
          self.quoted_message_type = quoted_message_type
        if role is not None:
          self.role = role
        if webhook_triggers is not None:
          self.webhook_triggers = webhook_triggers

    @property
    def action_size(self):
        """
        Gets the action_size of this Enums.

        :return: The action_size of this Enums.
        :rtype: str
        """
        return self._action_size

    @action_size.setter
    def action_size(self, action_size):
        """
        Sets the action_size of this Enums.

        :param action_size: The action_size of this Enums.
        :type: str
        """
        allowed_values = ["compact", "full", "tall"]
        if action_size not in allowed_values:
            raise ValueError(
                "Invalid value for `action_size` ({0}), must be one of {1}"
                .format(action_size, allowed_values)
            )

        self._action_size = action_size

    @property
    def action_type(self):
        """
        Gets the action_type of this Enums.

        :return: The action_type of this Enums.
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """
        Sets the action_type of this Enums.

        :param action_type: The action_type of this Enums.
        :type: str
        """
        allowed_values = ["buy", "link", "locationRequest", "postback", "reply", "share", "webview"]
        if action_type not in allowed_values:
            raise ValueError(
                "Invalid value for `action_type` ({0}), must be one of {1}"
                .format(action_type, allowed_values)
            )

        self._action_type = action_type

    @property
    def business_system_type(self):
        """
        Gets the business_system_type of this Enums.

        :return: The business_system_type of this Enums.
        :rtype: str
        """
        return self._business_system_type

    @business_system_type.setter
    def business_system_type(self, business_system_type):
        """
        Sets the business_system_type of this Enums.

        :param business_system_type: The business_system_type of this Enums.
        :type: str
        """
        allowed_values = ["helpscout", "slack", "zendesk"]
        if business_system_type not in allowed_values:
            raise ValueError(
                "Invalid value for `business_system_type` ({0}), must be one of {1}"
                .format(business_system_type, allowed_values)
            )

        self._business_system_type = business_system_type

    @property
    def client_status(self):
        """
        Gets the client_status of this Enums.

        :return: The client_status of this Enums.
        :rtype: str
        """
        return self._client_status

    @client_status.setter
    def client_status(self, client_status):
        """
        Sets the client_status of this Enums.

        :param client_status: The client_status of this Enums.
        :type: str
        """
        allowed_values = ["active", "blocked", "inactive", "pending"]
        if client_status not in allowed_values:
            raise ValueError(
                "Invalid value for `client_status` ({0}), must be one of {1}"
                .format(client_status, allowed_values)
            )

        self._client_status = client_status

    @property
    def confirmation_type(self):
        """
        Gets the confirmation_type of this Enums.

        :return: The confirmation_type of this Enums.
        :rtype: str
        """
        return self._confirmation_type

    @confirmation_type.setter
    def confirmation_type(self, confirmation_type):
        """
        Sets the confirmation_type of this Enums.

        :param confirmation_type: The confirmation_type of this Enums.
        :type: str
        """
        allowed_values = ["immediate", "userActivity", "prompt"]
        if confirmation_type not in allowed_values:
            raise ValueError(
                "Invalid value for `confirmation_type` ({0}), must be one of {1}"
                .format(confirmation_type, allowed_values)
            )

        self._confirmation_type = confirmation_type

    @property
    def conversation_activity_type(self):
        """
        Gets the conversation_activity_type of this Enums.

        :return: The conversation_activity_type of this Enums.
        :rtype: str
        """
        return self._conversation_activity_type

    @conversation_activity_type.setter
    def conversation_activity_type(self, conversation_activity_type):
        """
        Sets the conversation_activity_type of this Enums.

        :param conversation_activity_type: The conversation_activity_type of this Enums.
        :type: str
        """
        allowed_values = ["conversation:read", "typing:start", "typing:stop"]
        if conversation_activity_type not in allowed_values:
            raise ValueError(
                "Invalid value for `conversation_activity_type` ({0}), must be one of {1}"
                .format(conversation_activity_type, allowed_values)
            )

        self._conversation_activity_type = conversation_activity_type

    @property
    def deployment_activation_method(self):
        """
        Gets the deployment_activation_method of this Enums.

        :return: The deployment_activation_method of this Enums.
        :rtype: str
        """
        return self._deployment_activation_method

    @deployment_activation_method.setter
    def deployment_activation_method(self, deployment_activation_method):
        """
        Sets the deployment_activation_method of this Enums.

        :param deployment_activation_method: The deployment_activation_method of this Enums.
        :type: str
        """
        allowed_values = ["sms", "voice"]
        if deployment_activation_method not in allowed_values:
            raise ValueError(
                "Invalid value for `deployment_activation_method` ({0}), must be one of {1}"
                .format(deployment_activation_method, allowed_values)
            )

        self._deployment_activation_method = deployment_activation_method

    @property
    def deployment_hosting(self):
        """
        Gets the deployment_hosting of this Enums.

        :return: The deployment_hosting of this Enums.
        :rtype: str
        """
        return self._deployment_hosting

    @deployment_hosting.setter
    def deployment_hosting(self, deployment_hosting):
        """
        Sets the deployment_hosting of this Enums.

        :param deployment_hosting: The deployment_hosting of this Enums.
        :type: str
        """
        allowed_values = ["self", "smooch"]
        if deployment_hosting not in allowed_values:
            raise ValueError(
                "Invalid value for `deployment_hosting` ({0}), must be one of {1}"
                .format(deployment_hosting, allowed_values)
            )

        self._deployment_hosting = deployment_hosting

    @property
    def deployment_status(self):
        """
        Gets the deployment_status of this Enums.

        :return: The deployment_status of this Enums.
        :rtype: str
        """
        return self._deployment_status

    @deployment_status.setter
    def deployment_status(self, deployment_status):
        """
        Sets the deployment_status of this Enums.

        :param deployment_status: The deployment_status of this Enums.
        :type: str
        """
        allowed_values = ["deleting", "error", "integrated", "pending", "registered", "starting", "unregistered"]
        if deployment_status not in allowed_values:
            raise ValueError(
                "Invalid value for `deployment_status` ({0}), must be one of {1}"
                .format(deployment_status, allowed_values)
            )

        self._deployment_status = deployment_status

    @property
    def image_aspect_ratio(self):
        """
        Gets the image_aspect_ratio of this Enums.

        :return: The image_aspect_ratio of this Enums.
        :rtype: str
        """
        return self._image_aspect_ratio

    @image_aspect_ratio.setter
    def image_aspect_ratio(self, image_aspect_ratio):
        """
        Sets the image_aspect_ratio of this Enums.

        :param image_aspect_ratio: The image_aspect_ratio of this Enums.
        :type: str
        """
        allowed_values = ["horizontal", "square"]
        if image_aspect_ratio not in allowed_values:
            raise ValueError(
                "Invalid value for `image_aspect_ratio` ({0}), must be one of {1}"
                .format(image_aspect_ratio, allowed_values)
            )

        self._image_aspect_ratio = image_aspect_ratio

    @property
    def integration_status(self):
        """
        Gets the integration_status of this Enums.

        :return: The integration_status of this Enums.
        :rtype: str
        """
        return self._integration_status

    @integration_status.setter
    def integration_status(self, integration_status):
        """
        Sets the integration_status of this Enums.

        :param integration_status: The integration_status of this Enums.
        :type: str
        """
        allowed_values = ["active", "inactive", "error"]
        if integration_status not in allowed_values:
            raise ValueError(
                "Invalid value for `integration_status` ({0}), must be one of {1}"
                .format(integration_status, allowed_values)
            )

        self._integration_status = integration_status

    @property
    def integration_type(self):
        """
        Gets the integration_type of this Enums.

        :return: The integration_type of this Enums.
        :rtype: str
        """
        return self._integration_type

    @integration_type.setter
    def integration_type(self, integration_type):
        """
        Sets the integration_type of this Enums.

        :param integration_type: The integration_type of this Enums.
        :type: str
        """
        allowed_values = ["android", "api", "apn", "fcm", "ios", "line", "mailgun", "messagebird", "messenger", "telegram", "twilio", "twitter", "viber", "web", "wechat", "whatsapp"]
        if integration_type not in allowed_values:
            raise ValueError(
                "Invalid value for `integration_type` ({0}), must be one of {1}"
                .format(integration_type, allowed_values)
            )

        self._integration_type = integration_type

    @property
    def menu_item_type(self):
        """
        Gets the menu_item_type of this Enums.

        :return: The menu_item_type of this Enums.
        :rtype: str
        """
        return self._menu_item_type

    @menu_item_type.setter
    def menu_item_type(self, menu_item_type):
        """
        Sets the menu_item_type of this Enums.

        :param menu_item_type: The menu_item_type of this Enums.
        :type: str
        """
        allowed_values = ["link", "postback", "submenu"]
        if menu_item_type not in allowed_values:
            raise ValueError(
                "Invalid value for `menu_item_type` ({0}), must be one of {1}"
                .format(menu_item_type, allowed_values)
            )

        self._menu_item_type = menu_item_type

    @property
    def message_item_size(self):
        """
        Gets the message_item_size of this Enums.

        :return: The message_item_size of this Enums.
        :rtype: str
        """
        return self._message_item_size

    @message_item_size.setter
    def message_item_size(self, message_item_size):
        """
        Sets the message_item_size of this Enums.

        :param message_item_size: The message_item_size of this Enums.
        :type: str
        """
        allowed_values = ["compact", "large"]
        if message_item_size not in allowed_values:
            raise ValueError(
                "Invalid value for `message_item_size` ({0}), must be one of {1}"
                .format(message_item_size, allowed_values)
            )

        self._message_item_size = message_item_size

    @property
    def message_type(self):
        """
        Gets the message_type of this Enums.

        :return: The message_type of this Enums.
        :rtype: str
        """
        return self._message_type

    @message_type.setter
    def message_type(self, message_type):
        """
        Sets the message_type of this Enums.

        :param message_type: The message_type of this Enums.
        :type: str
        """
        allowed_values = ["carousel", "file", "image", "list", "location", "text", "form", "formResponse"]
        if message_type not in allowed_values:
            raise ValueError(
                "Invalid value for `message_type` ({0}), must be one of {1}"
                .format(message_type, allowed_values)
            )

        self._message_type = message_type

    @property
    def field_type(self):
        """
        Gets the field_type of this Enums.

        :return: The field_type of this Enums.
        :rtype: str
        """
        return self._field_type

    @field_type.setter
    def field_type(self, field_type):
        """
        Sets the field_type of this Enums.

        :param field_type: The field_type of this Enums.
        :type: str
        """
        allowed_values = ["text", "email", "select"]
        if field_type not in allowed_values:
            raise ValueError(
                "Invalid value for `field_type` ({0}), must be one of {1}"
                .format(field_type, allowed_values)
            )

        self._field_type = field_type

    @property
    def quoted_message_type(self):
        """
        Gets the quoted_message_type of this Enums.

        :return: The quoted_message_type of this Enums.
        :rtype: str
        """
        return self._quoted_message_type

    @quoted_message_type.setter
    def quoted_message_type(self, quoted_message_type):
        """
        Sets the quoted_message_type of this Enums.

        :param quoted_message_type: The quoted_message_type of this Enums.
        :type: str
        """
        allowed_values = ["message", "externalMessageId"]
        if quoted_message_type not in allowed_values:
            raise ValueError(
                "Invalid value for `quoted_message_type` ({0}), must be one of {1}"
                .format(quoted_message_type, allowed_values)
            )

        self._quoted_message_type = quoted_message_type

    @property
    def role(self):
        """
        Gets the role of this Enums.

        :return: The role of this Enums.
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """
        Sets the role of this Enums.

        :param role: The role of this Enums.
        :type: str
        """
        allowed_values = ["appMaker", "appUser"]
        if role not in allowed_values:
            raise ValueError(
                "Invalid value for `role` ({0}), must be one of {1}"
                .format(role, allowed_values)
            )

        self._role = role

    @property
    def webhook_triggers(self):
        """
        Gets the webhook_triggers of this Enums.

        :return: The webhook_triggers of this Enums.
        :rtype: str
        """
        return self._webhook_triggers

    @webhook_triggers.setter
    def webhook_triggers(self, webhook_triggers):
        """
        Sets the webhook_triggers of this Enums.

        :param webhook_triggers: The webhook_triggers of this Enums.
        :type: str
        """
        allowed_values = ["appUser:delete", "client:add", "client:remove", "conversation:read", "conversation:referral", "link:failure", "link:match", "link:success", "merge:appUser", "message:appMaker", "message:appUser", "message:delivery:channel", "message:delivery:failure", "message:delivery:user", "payment:success", "postback", "typing:appUser"]
        if webhook_triggers not in allowed_values:
            raise ValueError(
                "Invalid value for `webhook_triggers` ({0}), must be one of {1}"
                .format(webhook_triggers, allowed_values)
            )

        self._webhook_triggers = webhook_triggers

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Enums):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
